# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.5.x] 

### Added
- Migrate to python 3
- Migrate to Qt 5
- Add protection to create configuration folders 
- Add the axis as optional parameter on the script. 

### Fixed
- Fix classifiers to upload to PyPi

## [0.4.0] 

### Added
- Allow to save on the file
- Allow to save the setting to a file

### Fixed


## [0.3.0] 

### Added
- Allow to set the signals from command line.

### Fixed

## [0.2.1] 

### Added
- Update setting dialog: allows to configure the axis X.
- Allows to change the port

### Fixed
- Fix bug in setting and adjusted dialogs.
- Remove the possibility to open two settings dialogs. 
- Do not allow to open more than one setting dialog

## [0.1.0] 

### Added
- First version of the Oscilloscope mode.

### Fixed

#
[keepachangelog.com]: http://keepachangelog.com
[0.1.0]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.1.0...0.2.0
[0.2.1]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.2.0...0.2.1
[0.3.0]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.2.1...0.3.0
[0.4.0]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.3.0...0.4.0
[0.5.x]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.4.0...HEAD

